#define MFBPOLYGLYPHBLT xf1bppPolyGlyphBltWhite
#define OPEQ |=
#include "mfbmap.h"
#include "../../../../mfb/mfbplygblt.c"
